# Table of Contents

- [digital-operational-resilience-act-dora-attributes](<./digital-operational-resilience-act-dora-attributes.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Digital Operational Resilience Act (DORA) Attributes](<./Digital-Operational-Resilience-Act-DORA-Attributes.md>)
  - [Fields and Relations in Application and IT Component Fact Sheets](<./Digital-Operational-Resilience-Act-DORA-Attributes/Fields-and-Relations-in-Application-and-IT-Component-Fact-Sheets.md>)
  - [Fields and Relations in Business Context Fact Sheets](<./Digital-Operational-Resilience-Act-DORA-Attributes/Fields-and-Relations-in-Business-Context-Fact-Sheets.md>)
  - [Fields and Relations in Provider Fact Sheet](<./Digital-Operational-Resilience-Act-DORA-Attributes/Fields-and-Relations-in-Provider-Fact-Sheet.md>)
  - [Was this page helpful?](<./Digital-Operational-Resilience-Act-DORA-Attributes/Was-this-page-helpful.md>)
